@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
 // MPEG-4 audio, using LATM multiplexing
 // Implementation
 
@@ -145,16 +145,19 @@ static Boolean getNibble(char const*& configStr,
 }
 
 static Boolean getByte(char const*& configStr, unsigned char& resultByte) {
+  resultByte = 0; // by default, in case parsing fails
+
   unsigned char firstNibble;
   if (!getNibble(configStr, firstNibble)) return False;
+  resultByte = firstNibble<<4;
 
   unsigned char secondNibble = 0;
   if (!getNibble(configStr, secondNibble) && configStr[0] != '\0') {
     // There's a second nibble, but it's malformed
     return False;
   }
+  resultByte |= secondNibble;
 
-  resultByte = (firstNibble<<4)|secondNibble;
   return True;
 }
 
@@ -241,18 +244,16 @@ unsigned char* parseGeneralConfigStr(char const* configStr,
   unsigned char* config = NULL;
   do {
     if (configStr == NULL) break;
-    configSize = (strlen(configStr)+1)/2 + 1;
+    configSize = (strlen(configStr)+1)/2;
 
     config = new unsigned char[configSize];
     if (config == NULL) break;
 
-    Boolean parseSuccess;
-    unsigned i = 0;
-    do {
-      parseSuccess = getByte(configStr, config[i++]);
-    } while (parseSuccess);
-    if (i != configSize) break;
-        // part of the remaining string was bad
+    unsigned i;
+    for (i = 0; i < configSize; ++i) {
+      if (!getByte(configStr, config[i])) break;
+    }
+    if (i != configSize) break; // part of the string was bad
 
     return config;
   } while (0);
@@ -261,4 +262,3 @@ unsigned char* parseGeneralConfigStr(char const* configStr,
   delete[] config;
   return NULL;
 }
-
